# Response to Reviewer UWrD (part 1/2)

We thank reviewer UWrD for all the additional suggestions regarding our work. We have made targeted revisions and additions. For the revisions of the paper, we have marked them in **green** in the PDF.

## Major Issues

**Prior Works:**

- **About the similarity:** We acknowledge the similarities between our work and those of Schwarzenberg et al and Chuang et al, but it should be noted that both works not only deal with Shapley value computation. Firstly, Schwarzenberg et al proposed a general framework based on the concept of amortized estimation, in which a single neural network is trained to predict the IG / Shapley value for each player (either a pixel in an image or a token in text). Secondly, Chuang et al's work is rooted in RTX, which is fundamentally equivalent to amortized estimation (with FastSHAP mentioned as the first line of work or the RTX paradigm.)
- **About the difference:** However, there are also notable distinctions. Schwarzenberg et al ensures accuracy in the first term of their Eq.1: $argmin_{\theta\in \Theta}\frac{1}{\left|X\right|}\sum_{x\in \textbf{X}}\alpha D(E_f(x), e_{\theta}(x)) + \beta(\frac{\left\|e_{\theta}(x)\right\|}{\left\|E_{f}(x)\right\|})$. If we were to utilize ground truth labels, our framework would align with this approach, matching the $E_f(x)$ of the above equation, indicating the expensive explainer. Nevertheless, we didn't apply any form of supervision, instead relying solely on sampled ground truth data for our MSE computations. For Chuang et al, it is mentioned in the Introduction section of CoRTX that methods like Fastshap "learn an explainer to minimize the estimation error regarding to the approximated explanation labels". We concur with this assessment, though CoRTX does not provide a definitive explanation on this matter. Here we would like to **emphasize our primary contribution**, which is to unify current frameworks of Shapley Values estimation. FastSHAP, based on our Eq. 13, represents a specific example of approximation with a complicated metric matrix, and Schwarzenberg et al and Chuang et al can also be seen as a specific example of our proposed framework.
- **About the motivation for proposing SimSHAP:** We admit that the proposed SimSHAP is indeed insufficiently motivated. Our motivation stems from the fact that within a unified framework, we can select the semi-value equation and Identity matrix due to their simplicity. Additionally, we aim to identify the optimal metric matrix that maximizes performance in terms of optimization convergence as our future work.

We have revised our paper according to the reviewer's suggestions.

**Similarity of semivalue and least squares estimators:**

- **About the comparable time complexity:** Besides the unified framework, we would also like to emphasize that the time complexity of SimSHAP and FastSHAP is comparable, which corresponds to the amortized estimation version of semi value and least squares value. We have provided detailed analysis in our Appendix A.10. We also want to clarify that our focus is on the **static properties** of the algorithms, rather than the dynamic optimization properties.
- **About the naming of "least squares estimator":** We have carefully reviewed our paper and did not find the term "least squares estimator" anywhere in the text. Additionally, we mentioned the "least squares value" in Section 2.1 and explained that it is equivalent to the definition of the Shapley value, which it has nothing to do with the estimation strategies such as Monte Carlo Sampling discussed later in the paper.

**FastSHAP's equivalence to eq. 13:**

Thanks for the reviewer for pointing out the $\infty$ entries issue.

In our paper, all references to W pertain to the non-empty proper subset of W, implying that W encompasses a total of $2^d-2$ dimensions. We have taken into account two special scenarios that might contain $\infty$ values (relevant symbol definitions can be found below Eq. 12 and in Appendix A.1)

**Noisy Labels:**

Thanks for the reviewer for providing detailed derivation about fiting with noisy labels. This proof is quite intricate and we have updated our approach with this more refined proof.

- **About training with limited data:**  Since Mean Squared Error (MSE) is a strongly convex function, an upper bound can be derived analogously in the case of finite samples as Theorem 1 in the ViT paper [1].
- **About comparison with [1]:** We admit that the current treatment of this topic is a bit shallow. In our revised paper, we have derived an error bound for SimSHAP, providing a theoretical foundation for training without ground truth labels. Additionally, as part of our future work, we aim to identify the optimal metric matrix that maximizes performance in terms of optimization convergence.










# Response to Reviewer UWrD (part 2/2)

## Major Issues

**Issue for Definition 3:**

- **About the objective's optimum under different metric matrices:** For different metric matrices to achieve an equivalent optimal objective, they must be positive definite; otherwise, additional regularization terms are necessary for correction.
- **About the approximation of $\phi_{x}$:** Thanks for the reviewer for the suggestion. We have identified the imprecision in our statement, and have addressed these issues in the revised version of our paper. For simplicity, our Eq. 12 focuses on the derivation of the case where $\phi_{x}$ represents an exact value.

**About Appendix A.7 results:**

Thanks for the reviewer for the suggestion. However, due to time constraints, we are unable to implement these modifications in this current rebuttal phase. We intend to address these concerns in subsequent revisions as part of our future work. 

- **About CIFAR 10 result on data size:** Additionally, we would like to draw attention to our previous CIFAR-10 experiments on different dataset sizes in Table 12. Through these two investigations, we can at least demonstrate that when the dataset is extremely small, it may result in overfitting of noise, which is in line with our theoretical derivations.

**Figure 4 vs. Table 3:**

We're double-checking the details of this experiment and sorry for the late reply. Previously, we normalize the score curve to begin with 0 for insertion (1 for deletion) and end with 1 for insertion (0 for deletion).  While computing the mean and standard deviation, we only satisfy that the network output for the **original image (grand coalition)** is the same. That's why inconsistency is posed. We only enforced the latter constraint now and we can ensure the consistency between Figure 4 and Table 3. 



## Other Issues

We appreciate the reviewer's attention to comprehensive understanding of our paper and detailed suggestions.

**W1:**

We have added the clarification right after $v(S)= f(1^S\cdot x)$ to clarify the notation and avoid any possible confusion.

**W2:**

The reviewer is right about the unbiased Kernelshap estimation. We have modified Eq.5 in our latest revision.

**W3:**

We admit it's not rigorous enough to derive from the law of large numbers to the convergence rate. We would like to clarifty that the Lindeberg-Levy Central Limit Theorem (CLT), the variance of the random variable is related to the quantity M and is of order $\mathcal{O}(1/\sqrt{M})$.

**W4:**

**About model selection:** For fairness in evaluation, we choose the same model as FastSHAP.

**About Tuning Hyperparameters:** We employed grid search to find the best set of hyperparamters.

**About Early Stopping:** We did not implement a carefully designed training procedure, so we did not utilize the technique of early stopping.


### References:

[1] Covert et al, "Learning to Estimate Shapley Values with Vision Transformers" (2022)