# Response to Reviewer MdhR

We thank reviewer MdhR for the affirmation and pertinent suggestions on our work.
In response to the issues raised by the reviewer, we have made the following revisions and additions.
For the revisions of the paper, we have marked them in **green** in the PDF.

## Weaknesses

We thank for all the weaknesses pointed out, which greatly helped us revise our work. 

**W1:** 

We apologize for any confusion caused. We have carefully proofread and modified the text based on the reviewer's feedback.

**W2:** 

It is crucial to highlight that SimSHAP belongs to the class of amortized Shapley Value estimators, and amortized techniques generally exhibit faster speeds than their non-amortized counterparts. Compared to FastSHAP, SimSHAP can achieve a **comparable** inference speed, without the need for normalization during inference.

Furthermore, this article places greater emphasis on proposing a unified framework for computing Shapley values, and in the future, we intend to further explore the acceleration issue of amortized estimators from a theoretical standpoint.

## Questions

We really appreciate the reviewer's thorough examination of our work and all the insightful questions that the reviewer has raised. We have made the following adjustments to address the concerns:

**Q1:**

We recognize that there is room for improvement in our notations. We have streamlined the notation and removed any potential confusion.

**Q2:** 

Thank you for recommending additional related literature. We have incorporated more references on model-specific Shapley value estimation into our revised manuscript.

**Q3:**

We agree that the previous presentation of **Definition 2** could be confusing. We have restructured this definition as: 
> **Unified Stochastic Estimator** is defined as the linear transformation of the values obtained from sampled subsets $\bm{S}$.

**Q4:**

You're right that the high standard deviation values in our experiments might be misleading. 
To address this concern, we re-examined the calculation methods for metrics and implemented the bootstrap strategy recommended by FastSHAP. 
As a result, we observed a significant reduction in the standard deviation, which is clearly reflected in Table 3 of our updated version.

**Q5:**

Thank you for highlighting the importance of our inference speed advantage. We have emphasized this aspect in multiple sections of the "Experiments" section.

**Q6:**

Ground Truth Shapley value computation is not fully precise in our experiment. 
We used the `shapreg` package[^1] for the ground truth computation, which allows users to specify an error bound and compute a satisfactory ground truth Shapley value within a reasonable time span.

## Minor

We are grateful for the minor suggestions by the reviewer in terms of writing.

**Q1:**

The reviewer raises an important point in this statement. We have revised the Introduction section to more clearly highlight the profound impact of deep learning techniques on various industries, due to their remarkable ability to learn complex functions both quickly and accurately.

**Q2:**

We acknowledge that the use of "and" in this sentence may cause some confusion, as it does not intend to establish a connection between the two sub-sentences. 
What we are trying to convey is that cooperative games do not involve the choice of value functions, whereas machine learning models are not considered cooperative games, necessitating the consideration of value function choices. 
Additionally, the complexity of computing Shapley values grows exponentially with the data dimension $d$, thus requiring the exploration of efficient estimation strategies. We have revised this portion of the text in the latest version of our paper to clarify these points.

**Q3-6:**

We appreciate the reviewer's careful reading. The suggestions for details are helpful and we have modified our paper based on them.

### Reference:
[1] https://github.com/iancovert/shapley-regression

----------------------------------------------------------------
# Response to Reviewer UWrD (part 1/2)

We thank reviewer UWrD for all the helpful critiques and suggestions regarding our work. We have made targeted revisions and additions.
For the revisions of the paper, we have marked them in **green** in the PDF.

## About the main methodological contributions

**W1:**

Thanks for reviewer's suggestions, we have added two references to the revised version.
- **About missing references:** We also noticed these works in our methodological survey, and we acknowledge that there have been some research efforts on amortized estimators in recent years, such as the FastSHAP method cited in our paper. 
- **About contributions:** We apologize for the unclear parts in the paper, but we still want to emphasize the main contributions of this paper. 
Many recent works have studied different estimation methods for approximating Shapley values, such as **semi-value** (ordinary Monte Carlo estimation) and **least-square value** (using the weighted least squares property of Shapley values). 
However, we found that these methods are **essentially not different**.
We find that the least-square value is essentially still equivalent to some special probability Monte Carlo estimator. 
Therefore, we propose a unified perspective of stochastic estimators and build a unified perspective of amortized estimators on this basis.
We have emphasized the main contributions of the paper in the revised version.

**W2:**

Sorry for the confusion in the original paper. 
- **Least-square value & unified perspective:** Regarding whether the least-square value can be incorporated into our unified perspective, we have provided detailed analysis and rigorous proof in **Appendix A.1**.
- **About unbiased kernelSHAP:** Thanks to the reviewer for pointing out that we did use the **unbiased kernelSHAP** in this work, and we have made it clearer in the revised version to eliminate any possible confusion.
- **Proof of Eq(14):** Regarding the proof of the unbiasedness of the original formula 14, we have provided detailed derivations in **Appendix A.2** and ensured its unbiasedness.

**W3:**

Thanks for the suggestion. 
- **About the fitting priority of information with different frequency:** We acknowledge the need to clarify how the model can be trained on noisy data. We have added the analysis in **Appendix A.4**. 
- **Supplementary exprimental results:** The model can ensure a fit to the true value if the training set is large enough. 
As the reviewer pointed out, a small dataset can cause the model to overfit the noise and fail to capture the true value. We plan to research ways to learn the true value with limited data as our future direction. We have demonstrated the above statement with experiments in **Appendix A.7**. Furthermore, our sampling strategy guarantees convergence to the ground truth value when operating on sufficient amount of data. Together with Table 12 in **Appendix A.6**, we can ensure the feasibility of our algorithm.

**W4:**

- **About the theoretical derivation of Eq(13):** We are sorry to have deleted the theoretical derivation due to the page limit. We can ensure its rightness and have included the whole proof in **Appendix A.3**. 
- **About $\phi_x$'s analysis:** In addition, we admit the inaccuracy of $\phi_x$ to Shapley values. That's why we add the $\frac{v(N) - v(\phi)}{d}\textbf{1}$ term to make it strictly equal to Shapley values, which is also a technical difference between **SimSHAP** and **FastSHAP**. 
  - **For FastSHAP:** FastSHAP utilizes normalization/penalty punishment terms in the loss to ensure correctness. 
  - **For SimSHAP:** We have found that the issue can be resolved by simply incorporating this term into the calculation of the sampled ground truth, allowing for the construction of SimSHAP without the need for normalization or penalty in the end.
- **About the main point of FastSHAP:** We acknowledge its contribution by bypassing the need for the ground truth labels. Here we would like to reiterate our contribution in unifying and proposing SimSHAP: 
  - for stochastic estimator (Table 1), we demonstrated that the least squares value with KKT condition is equivalent to direct Monte-Carlo sampling on the classic form of Shapley values computation. This serves as the answer to why we didn't discover a significant difference in computational complexity (see **Appendix A.1**). 
  - What's more, We would emphasize that SimSHAP bypasses the need for ground truth Shapley values labels as well, but we choose the simplest metric and function as a result of our unified framework.

**W5:**

We have addressed the questions above, primarily on W4.

## About the experiments

**Q1:**

Thanks for the insightful suggestion. 
- The results in **Appendix A.6-7** demonstrate that significantly enlarging the sample size can notably enhance the model's fitting performance, but it also introduces additional computational burdens.
- To maintain consistent training times compared to the baseline approach, the results depicted in **Figure 2** do not incorporate a large sample size. Future research endeavors will focus on exploring how to achieve superior fitting outcomes with smaller sample sizes, as outlined in **W3 in part 1**.

**Q2:** (暂时没有上传)

Thanks for the reviewers' insightful suggestions. 
- **About the inconsistency:** After re-examining our comparison code, we discovered that the inconsistency in the original figures was caused by an additional normalization step during the calculation of AUC. This issue has been rectified in the updated version, and the chart results have also been revised accordingly. 
- **Highlight our core contributions:** It's crucial to note that our proposed method is a competitive approach, rather than one that necessarily outperforms FastSHAP. The primary contribution of this paper is to introduce a unified framework, which reveals that typical estimation strategies, such as least squares value and semivalue, have no essential differences. Additionally, we propose the SimSHAP algorithm based on this framework, which simplifies the selection of a metric matrix without requiring additional normalization.

## About the writing

We appreciate the reviewer's attention to detail and comprehensive understanding of our paper. 

**Q1:**

We admit our incorrectness in the "Related Work" section and "Introduction" section. 
- Regarding terms such as semivalue, we follow the terminology used in [1].
- We have revised the paper and modified "reduce computation cost by merging or pruning redundant feature combinations" to "introduce model-specific information" in order to be more appropriate and accurate. 
- Moreover, we have to clarify "the exact differences among these algorithms remain unclear". Our motivation is that there are so many model-agnostic methods for Shapley values estimation and we sometimes don't know which method to choose for a specific scenario, so we turned to explore their differences in essence. We thus articulated this motivation in the new version of our paper.

**Q2:**

We apologize for not double-checking the official term for "law of large numbers". In addition, We are referring to the convergence of the sample mean to the expectation by mentioning $O(\frac{1}{\sqrt{M}})$, and we think the reviewer's suggestion makes the statement more precise. 

**Q3:** 

We have proofed **proposition 1** in **Appendix A.1**, and we also accept the advice to emphasize the result by citing the work the reviewer mentioned.

**Q4:** 

We apologize for any confusion in the notation system. 
We have organized the symbols in the new version.

**Q5:**

The reviewer is right as we did not intend to demonstrate the FastSHAP loss as a biased loss, but it needs to be normalized which corresponds to satisfying the efficiency constraint. It's also worth mentioning that we added one term instead of performing normalization for Shapley values correction in our algorithm, as stated in **W4** for weakness.

**Q6-7:** 

We acknowledge that we followed FastSHAP's experimental setup to provide a systematic evaluation of our method. 
We have clearly stated this in the revised version of the paper and have also corrected all the typos pointed out by the reviewer, which has contributed to a more organized and precise presentation.

### Reference:

[1] Algorithms to estimate Shapley value feature attributions, Chen, Hugh and Covert, Ian C and Lundberg, Scott M and Lee, Su-In, Nature Machine Intelligence, 2023

